.. currentmodule:: sardana.tango.pool.CTExpChannel

:mod:`~sardana.tango.pool.CTExpChannel`
=========================================

.. automodule:: sardana.tango.pool.CTExpChannel

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`CTExpChannel`
    * :class:`CTExpChannelClass`

CTExpChannel
-------------

.. inheritance-diagram:: CTExpChannel
    :parts: 1
    
.. autoclass:: CTExpChannel
    :show-inheritance:
    :members:
    :undoc-members:

CTExpChannelClass
------------------

.. inheritance-diagram:: CTExpChannelClass
    :parts: 1
    
.. autoclass:: CTExpChannelClass
    :show-inheritance:
    :members:
    :undoc-members:

